==> dtk6declarative-debug-6.0.29-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/qml/settings/.qt/rcc/qrc_qmake_org_deepin_dtk_settings.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xfe,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x74,0x6b,0x2e,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0xa,0x6c,0x69,
  0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,
  0x61,0x72,0x61,0x74,0x69,0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,
  0x6c,0x75,0x67,0x69,0x6e,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,
  0x6c,0x75,0x67,0x69,0x6e,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,0x61,0x72,0x61,
  0x74,0x69,0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,0x67,
  0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,0x64,0x74,0x6b,0x5f,0x73,0x65,0x74,0x74,
  0x69,0x6e,0x67,0x73,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,
  0x6e,0x66,0x6f,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,0x61,0x72,0x61,0x74,0x69,
  0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,0x6c,0x75,0x67,0x69,0x6e,
  0x2e,0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,
  0x20,0x3a,0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x64,0x74,
  0x6b,0x2f,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x2f,0xa,0x53,0x65,0x74,0x74,
  0x69,0x6e,0x67,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,
  0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x4f,0x70,0x74,0x69,0x6f,0x6e,0x44,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,
  0x20,0x31,0x2e,0x30,0x20,0x4f,0x70,0x74,0x69,0x6f,0x6e,0x44,0x65,0x6c,0x65,0x67,
  0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x68,0x65,0x63,0x6b,0x42,0x6f,0x78,
  0x20,0x31,0x2e,0x30,0x20,0x43,0x68,0x65,0x63,0x6b,0x42,0x6f,0x78,0x2e,0x71,0x6d,
  0x6c,0xa,0x4c,0x69,0x6e,0x65,0x45,0x64,0x69,0x74,0x20,0x31,0x2e,0x30,0x20,0x4c,
  0x69,0x6e,0x65,0x45,0x64,0x69,0x74,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x6f,0x6d,0x62,
  0x6f,0x42,0x6f,0x78,0x20,0x31,0x2e,0x30,0x20,0x43,0x6f,0x6d,0x62,0x6f,0x42,0x6f,
  0x78,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x61,0x76,0x69,0x67,0x61,0x74,0x69,0x6f,0x6e,
  0x54,0x69,0x74,0x6c,0x65,0x20,0x31,0x2e,0x30,0x20,0x4e,0x61,0x76,0x69,0x67,0x61,
  0x74,0x69,0x6f,0x6e,0x54,0x69,0x74,0x6c,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x6f,
  0x6e,0x74,0x65,0x6e,0x74,0x54,0x69,0x74,0x6c,0x65,0x20,0x31,0x2e,0x30,0x20,0x43,
  0x6f,0x6e,0x74,0x65,0x6e,0x74,0x54,0x69,0x74,0x6c,0x65,0x2e,0x71,0x6d,0x6c,0xa,
  0x43,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,
  0x64,0x20,0x31,0x2e,0x30,0x20,0x43,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x42,0x61,0x63,
  0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // settings
  0x0,0x8,
  0xc,0xbb,0xb,0xc3,
  0x0,0x73,
  0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,
  // :/org/deepin/dtk/settings
  0x0,0x0,0x0,0x2a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,
  // :/org/deepin/dtk/settings/qmldir
  0x0,0x0,0x0,0x40,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x95,0xfd,0x45,0x44,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> dtk6declarative-debug-6.0.30-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/qml/settings/.qt/rcc/qrc_qmake_org_deepin_dtk_settings.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xfe,
  0x6d,
  0x6f,0x64,0x75,0x6c,0x65,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x74,0x6b,0x2e,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0xa,0x6c,0x69,
  0x6e,0x6b,0x74,0x61,0x72,0x67,0x65,0x74,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,
  0x61,0x72,0x61,0x74,0x69,0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,
  0x6c,0x75,0x67,0x69,0x6e,0xa,0x6f,0x70,0x74,0x69,0x6f,0x6e,0x61,0x6c,0x20,0x70,
  0x6c,0x75,0x67,0x69,0x6e,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,0x61,0x72,0x61,
  0x74,0x69,0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,0x6c,0x75,0x67,
  0x69,0x6e,0xa,0x63,0x6c,0x61,0x73,0x73,0x6e,0x61,0x6d,0x65,0x20,0x6f,0x72,0x67,
  0x5f,0x64,0x65,0x65,0x70,0x69,0x6e,0x5f,0x64,0x74,0x6b,0x5f,0x73,0x65,0x74,0x74,
  0x69,0x6e,0x67,0x73,0x50,0x6c,0x75,0x67,0x69,0x6e,0xa,0x74,0x79,0x70,0x65,0x69,
  0x6e,0x66,0x6f,0x20,0x64,0x74,0x6b,0x64,0x65,0x63,0x6c,0x61,0x72,0x61,0x74,0x69,
  0x76,0x65,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x70,0x6c,0x75,0x67,0x69,0x6e,
  0x2e,0x71,0x6d,0x6c,0x74,0x79,0x70,0x65,0x73,0xa,0x70,0x72,0x65,0x66,0x65,0x72,
  0x20,0x3a,0x2f,0x6f,0x72,0x67,0x2f,0x64,0x65,0x65,0x70,0x69,0x6e,0x2f,0x64,0x74,
  0x6b,0x2f,0x73,0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x2f,0xa,0x53,0x65,0x74,0x74,
  0x69,0x6e,0x67,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x20,0x31,0x2e,0x30,0x20,0x53,
  0x65,0x74,0x74,0x69,0x6e,0x67,0x73,0x44,0x69,0x61,0x6c,0x6f,0x67,0x2e,0x71,0x6d,
  0x6c,0xa,0x4f,0x70,0x74,0x69,0x6f,0x6e,0x44,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,
  0x20,0x31,0x2e,0x30,0x20,0x4f,0x70,0x74,0x69,0x6f,0x6e,0x44,0x65,0x6c,0x65,0x67,
  0x61,0x74,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x68,0x65,0x63,0x6b,0x42,0x6f,0x78,
  0x20,0x31,0x2e,0x30,0x20,0x43,0x68,0x65,0x63,0x6b,0x42,0x6f,0x78,0x2e,0x71,0x6d,
  0x6c,0xa,0x4c,0x69,0x6e,0x65,0x45,0x64,0x69,0x74,0x20,0x31,0x2e,0x30,0x20,0x4c,
  0x69,0x6e,0x65,0x45,0x64,0x69,0x74,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x6f,0x6d,0x62,
  0x6f,0x42,0x6f,0x78,0x20,0x31,0x2e,0x30,0x20,0x43,0x6f,0x6d,0x62,0x6f,0x42,0x6f,
  0x78,0x2e,0x71,0x6d,0x6c,0xa,0x4e,0x61,0x76,0x69,0x67,0x61,0x74,0x69,0x6f,0x6e,
  0x54,0x69,0x74,0x6c,0x65,0x20,0x31,0x2e,0x30,0x20,0x4e,0x61,0x76,0x69,0x67,0x61,
  0x74,0x69,0x6f,0x6e,0x54,0x69,0x74,0x6c,0x65,0x2e,0x71,0x6d,0x6c,0xa,0x43,0x6f,
  0x6e,0x74,0x65,0x6e,0x74,0x54,0x69,0x74,0x6c,0x65,0x20,0x31,0x2e,0x30,0x20,0x43,
  0x6f,0x6e,0x74,0x65,0x6e,0x74,0x54,0x69,0x74,0x6c,0x65,0x2e,0x71,0x6d,0x6c,0xa,
  0x43,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,
  0x64,0x20,0x31,0x2e,0x30,0x20,0x43,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x42,0x61,0x63,
  0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x2e,0x71,0x6d,0x6c,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // dtk
  0x0,0x3,
  0x0,0x0,0x6b,0xab,
  0x0,0x64,
  0x0,0x74,0x0,0x6b,
    // settings
  0x0,0x8,
  0xc,0xbb,0xb,0xc3,
  0x0,0x73,
  0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/org/deepin
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/org/deepin/dtk
  0x0,0x0,0x0,0x1e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/org/deepin/dtk/settings
  0x0,0x0,0x0,0x2a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,
  // :/org/deepin/dtk/settings/qmldir
  0x0,0x0,0x0,0x40,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x96,0x20,0xda,0x36,0xf0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_deepin_dtk_settings)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_deepin_dtk_settings)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
